%global pkgname lpres

Name:           gap-pkg-%{pkgname}
Version:        0.3.1
Release:        1%{?dist}
Summary:        Nilpotent quotients of L-presented groups

License:        GPLv2+
URL:            https://laurentbartholdi.github.io/lpres/
Source0:        https://github.com/laurentbartholdi/lpres/releases/download/v%{version}/%{pkgname}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  gap-devel
BuildRequires:  GAPDoc-latex
BuildRequires:  gap-pkg-ace
BuildRequires:  gap-pkg-ace-doc
BuildRequires:  gap-pkg-autpgrp
BuildRequires:  gap-pkg-fga
BuildRequires:  gap-pkg-nq
BuildRequires:  gap-pkg-polycyclic

Requires:       gap-core
Requires:       gap-pkg-fga
Requires:       gap-pkg-polycyclic

Recommends:     gap-pkg-ace
Recommends:     gap-pkg-autpgrp
Recommends:     gap-pkg-nq

%description
The lpres package provides a first construction of finitely L-presented
groups and a nilpotent quotient algorithm for L-presented groups.  The
features of this package include:
- creating an L-presented group as a new gap object,
- computing nilpotent quotients of L-presented groups and epimorphisms
  from the L-presented group onto its nilpotent quotients,
- computing the abelian invariants of an L-presented group,
- computing finite-index subgroups and if possible their L-presentation,
- approximating the Schur multiplier of L-presented groups.

%prep
%setup -q -n %{pkgname}-%{version}

%build
# Link to main GAP documentation
ln -s %{_gap_dir}/doc ../../doc
mkdir ../pkg
ln -s ../%{pkgname}-%{version} ../pkg/%{pkgname}
gap -l "$PWD/..;%{_gap_dir}" << EOF
LoadPackage("lpres");
MakeGAPDocDoc( "doc", "lpres.xml", [], "lpres", "../../..", "MathJax" );
CopyHTMLStyleFiles( "doc" );
GAPDocManualLab( "lpres" );
EOF
rm -fr ../../doc ../pkg

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname}-%{version} %{buildroot}%{_gap_dir}/pkg/%{pkgname}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{COPYING,README}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,brf,idx,ilg,ind,log,out,pnr,tex,toc}

%check
cd tst
gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" << EOF 2>&1 | tee log
LoadPackage("lpres");
Test("manual.tst", rec( compareFunction := "uptowhitespace" ));
Test("res.tst", rec( compareFunction := "uptowhitespace" ));
EOF
grep -Fvq fail log
rm -f log

%files
%doc README
%license COPYING
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%docdir %{_gap_dir}/pkg/%{pkgname}/htm
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Thu Sep 22 2016 Jerry James <loganjerry@gmail.com> - 0.3.1-1
- New upstream version

* Fri Sep 16 2016 Jerry James <loganjerry@gmail.com> - 0.3.0-1
- Initial RPM
